@@ -22,7 +22,7 @@ from ._marker import Marker
 from .version import version
 
 # for unit tests
-from ._timer import Timer
+from ._notations import Jab_to_factors
 
 # package version
 import pkg_resources
@@ -43,7 +43,6 @@ __all__ = [
     'read_dct', 'read_spatial', 'from_spatial', 'from_dct', 'to_jpegio',
     'SpatialJPEG', 'DCTJPEG', 'DCTJPEGio',
     'Colorspace', 'DCTMethod', 'Dithermode', 'Marker',
-    'version',
-    'Timer', 'dct',
+    'version', 'Jab_to_factors',
     '__version__',
 ]
